@@ -106,7 +106,7 @@ class ContainerRestartsDiaglet(Diaglet):
                     [
                         f"There are {total_restarts} restarts across {total_instances} simulator instances.",
                         "This is commonly due to errors during simulator execution.",
-                        "See https://docs.microsoft.com/bonsai/ui/sim-restart to learn about common causes and remedies for restarts.",
+                        "See https://docs.microsoft.com/bonsai/cli/sim-restarts to learn about common causes and remedies for restarts.",
                     ]
                 )
             elif total_instances > 0:
