@@ -3,6 +3,7 @@ from typing import Any, Dict, List, Tuple
 import sys
 import platform
 import subprocess
+import logging
 
 from datetime import timedelta
 from bonsai_cli.commands.diaglets.diaglet_configuration import DiagletConfiguration
@@ -14,6 +15,7 @@ from azure.identity import (
     SharedTokenCacheCredential,
     TokenCachePersistenceOptions,
 )
+
 from azure.core.credentials import TokenCredential
 from azure.monitor.query import LogsQueryClient, LogsQueryStatus
 from azure.monitor.query._models import LogsTable
@@ -182,6 +184,42 @@ class Diaglet:
 
         chained_credential: Any = None
 
+        ###
+        # 1. check if the user has valid shared credentials that could be used
+        # 2. check if the user has the Azure CLI
+        # 3. if all else fails, use the device code credential
+        ###
+
+        use_shared_credential: bool = False
+        use_cli_credential: bool = False
+
+        shared_token_cache_credential = SharedTokenCacheCredential()
+        azure_cli_credential = AzureCliCredential()
+        device_code_credential = DeviceCodeCredential(
+            cache_persistence_options=TokenCachePersistenceOptions(
+                allow_unencrypted_storage=True
+            )
+        )
+
+        # prevent the confusing output
+        logger = logging.getLogger("azure")
+        current_level = logger.getEffectiveLevel()
+        logger.setLevel(logging.CRITICAL)
+
+        try:
+            az_mgmt_scope = "https://management.azure.com/.default"
+            az_log_analytics_scope = "https://api.loganalytics.io/.default"
+
+            shared_token_cache_credential.get_token(az_mgmt_scope)
+            shared_token_cache_credential.get_token(az_log_analytics_scope)
+
+            use_shared_credential = True
+        except:
+            use_shared_credential = False
+
+        # reset it to what it was
+        logger.setLevel(current_level)
+
         try:
             command = "az account list"
 
@@ -203,24 +241,26 @@ class Diaglet:
 
             subprocess.check_output(args, **kwargs)
 
-            chained_credential = ChainedTokenCredential(
-                SharedTokenCacheCredential(),
-                AzureCliCredential(),
-                DeviceCodeCredential(
-                    cache_persistence_options=TokenCachePersistenceOptions(
-                        allow_unencrypted_storage=True
-                    )
-                ),
-            )
+            use_cli_credential = True
         except:
+            use_cli_credential = False
+
+        if use_shared_credential and use_cli_credential:
             chained_credential = ChainedTokenCredential(
-                SharedTokenCacheCredential(),
-                DeviceCodeCredential(
-                    cache_persistence_options=TokenCachePersistenceOptions(
-                        allow_unencrypted_storage=True
-                    )
-                ),
+                shared_token_cache_credential,
+                azure_cli_credential,
+                device_code_credential,
             )
+        elif use_shared_credential:
+            chained_credential = ChainedTokenCredential(
+                shared_token_cache_credential, device_code_credential
+            )
+        elif use_cli_credential:
+            chained_credential = ChainedTokenCredential(
+                azure_cli_credential, device_code_credential
+            )
+        else:
+            chained_credential = ChainedTokenCredential(device_code_credential)
 
         Diaglet.credential = chained_credential
 
