@@ -40,6 +40,6 @@ class IterationHaltedDiaglet(Diaglet):
                 [
                     f"There are {len(df)} halted iterations.",
                     "Halted iterations may impact brain training if not used with an avoid goal in inkling.",
-                    "See https://docs.microsoft.com/bonsai/ui/sim-halted to learn about common causes and remedies for halted conditions.",
+                    "See https://docs.microsoft.com/bonsai/cli/sim-halted to learn about common causes and remedies for halted conditions.",
                 ]
             )
