@@ -35,4 +35,4 @@ class SimTimeoutDiaglet(Diaglet):
         if len(df) == 0:
             self.message = f"There are no simulator timeouts."
         else:
-            self.message = f"There are {len(df)} simulator timeouts. See https://docs.microsoft.com/en-us/bonsai/troubleshoot/managed-sims/timeout to learn about common causes and remedies for timeouts."
+            self.message = f"There are {len(df)} simulator timeouts. See https://docs.microsoft.com/bonsai/cli/sim-timeout to learn about common causes and remedies for timeouts."
